@@ -1,3 +1,4 @@
+"""Test graph routings."""
 import numpy as np
 import scipy.sparse as sparse
 
@@ -97,7 +98,6 @@ class TestGraph(TestCase):
 
     def test_bellman_ford(self):
         """Test pile of cases against reference implementation."""
-
         np.random.seed(1643502758)
 
         for G in self.cases:
@@ -338,7 +338,7 @@ def test_connected_components():
         assert_equal(result.min(), 0)
 
         def array_to_set_of_sets(arr):
-            """convert array to set of sets format"""
+            """Convert array to set of sets format."""
             D = {}
             for i in set(arr):
                 D[i] = set()
@@ -415,7 +415,7 @@ def test_complex_connected_components():
         assert_equal(result.min(), 0)
 
         def array_to_set_of_sets(arr):
-            """convert array to set of sets format"""
+            """Convert array to set of sets format."""
             D = {}
             for i in set(arr):
                 D[i] = set()
